import { ManageIndexesApi } from '../pinecone-generated-ts-fetch/db_control';
import type { PineconeConfiguration } from '../data/vectors/types';
export declare const indexOperationsBuilder: (config: PineconeConfiguration) => ManageIndexesApi;
