import type { PineconeConfiguration } from '../data';
import { InferenceApi } from '../pinecone-generated-ts-fetch/inference';
export declare const inferenceOperationsBuilder: (config: PineconeConfiguration) => InferenceApi;
