import { IndexModel, ManageIndexesApi } from '../pinecone-generated-ts-fetch/db_control';
import type { IndexName } from './types';
/** The name of the index to describe */
export type DescribeIndexOptions = IndexName;
export declare const describeIndex: (api: ManageIndexesApi) => (indexName: DescribeIndexOptions) => Promise<IndexModel>;
