"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidPodTypes = void 0;
exports.ValidPodTypes = [
    's1.x1',
    's1.x2',
    's1.x4',
    's1.x8',
    'p1.x1',
    'p1.x2',
    'p1.x4',
    'p1.x8',
    'p2.x1',
    'p2.x2',
    'p2.x4',
    'p2.x8',
];
//# sourceMappingURL=types.js.map