import type { PineconeConfiguration } from '../data';
export declare const getFetch: (config: PineconeConfiguration) => (input: RequestInfo | URL, init?: RequestInit | undefined) => Promise<Response>;
