"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.debugLog = void 0;
var debugLog = function (str) {
    if (typeof process !== 'undefined' &&
        process &&
        process.env &&
        process.env.PINECONE_DEBUG) {
        console.log(str);
    }
};
exports.debugLog = debugLog;
//# sourceMappingURL=debugLog.js.map