import { ManageIndexesApi } from '../pinecone-generated-ts-fetch/db_control';
import { IndexName } from './types';
/** The name of index to delete */
export type DeleteIndexOptions = IndexName;
export declare const deleteIndex: (api: ManageIndexesApi) => (indexName: DeleteIndexOptions) => Promise<void>;
