import { BulkOperationsProvider } from './bulkOperationsProvider';
import type { ImportModel } from '../../pinecone-generated-ts-fetch/db_data';
export declare class DescribeImportCommand {
    apiProvider: BulkOperationsProvider;
    namespace: string;
    constructor(apiProvider: BulkOperationsProvider, namespace: string);
    run(id: string): Promise<ImportModel>;
}
