import { BulkOperationsProvider } from './bulkOperationsProvider';
export declare class CancelImportCommand {
    apiProvider: BulkOperationsProvider;
    namespace: string;
    constructor(apiProvider: BulkOperationsProvider, namespace: string);
    run(id: string): Promise<object>;
}
