import { ManageIndexesApi, CollectionModel } from '../pinecone-generated-ts-fetch/db_control';
import type { CollectionName } from './types';
/**
 * The name of collection to describe.
 */
export type DescribeCollectionOptions = CollectionName;
export declare const describeCollection: (api: ManageIndexesApi) => (name: DescribeCollectionOptions) => Promise<CollectionModel>;
