"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PineconeRecordsProperties = exports.PineconeConfigurationProperties = void 0;
exports.PineconeConfigurationProperties = [
    'apiKey',
    'controllerHostUrl',
    'fetchApi',
    'additionalHeaders',
    'sourceTag',
];
exports.PineconeRecordsProperties = [
    'id',
    'values',
    'sparseValues',
    'metadata',
];
//# sourceMappingURL=types.js.map