"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.X_PINECONE_API_VERSION = void 0;
exports.X_PINECONE_API_VERSION = '2024-10';
//# sourceMappingURL=api_version.js.map