import { ManageIndexesApi } from '../pinecone-generated-ts-fetch/db_control';
import type { CollectionName } from './types';
/**
 * The name of collection to delete.
 */
export type DeleteCollectionOptions = CollectionName;
export declare const deleteCollection: (api: ManageIndexesApi) => (collectionName: DeleteCollectionOptions) => Promise<void>;
