import { Middleware } from '../pinecone-generated-ts-fetch/db_control';
export declare const middleware: (Middleware | {
    onError: (context: any) => Promise<never>;
    post: (context: any) => Promise<any>;
})[];
