import type { VectorOperationsApi } from '../../../pinecone-generated-ts-fetch/db_data';
import { VectorOperationsProvider } from '../../vectors/vectorOperationsProvider';
export declare const setupDeleteSuccess: (response: any) => {
    VOA: VectorOperationsApi;
    VectorProvider: VectorOperationsProvider;
};
