import { VectorOperationsProvider } from './vectorOperationsProvider';
import { RecordId } from './types';
/**
 * The id of the record to delete from the index.
 *
 * @see {@link Index.deleteOne }
 */
export type DeleteOneOptions = RecordId;
export declare const deleteOne: (apiProvider: VectorOperationsProvider, namespace: string) => (options: DeleteOneOptions) => Promise<void>;
